package com.example.wholeestate.controller;


import com.example.wholeestate.common.base.BaseController;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.model.BuildingDynamic;
import com.example.wholeestate.service.IBuildingDynamicService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;

/**
 * <p>
 * 项目动态表 前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-03-21
 */
@RestController
@RequestMapping("/")
@Api(value = "项目动态管理API",description = "项目动态管理API")
public class BuildingDynamicController extends BaseController {

    @Autowired
    private IBuildingDynamicService iBuildingDynamicService;

    @InitBinder
    protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
        DateFormat df = new SimpleDateFormat("yyyy-MM-dd");
        CustomDateEditor editor = new CustomDateEditor(df, true);//true表示允许为空，false反之
        binder.registerCustomEditor(Date.class, editor);
    }

    @ApiOperation(value = "项目动态管理列表", notes = "项目动态管理列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "Query",dataType = "Integer",name = "pageNum",value = "分页第几页" ),
            @ApiImplicitParam(paramType = "Query",dataType = "Integer",name = "pageSize",value = "pageSize:每页长度")

    })
    @RequestMapping(value = "/iBuildingDynamicList", method = RequestMethod.GET)
    public ResponseBean iBuildingDynamicList(@RequestParam("pageNum")Integer pageNum,@RequestParam("pageSize")Integer pageSize, HttpSession session){
        ResponseBean  responseBean = iBuildingDynamicService.iBuildingDynamicList(pageNum,pageSize);
        return responseBean;
    }

    @RequestMapping(value = "/iBuildingDynamicSelectId/{id}", method = RequestMethod.GET)
    @ApiOperation(value = "项目动态详情", notes = "项目动态详情")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass=Integer.class, name = "id", value = "项目动态id"),
    })
    public ResponseBean iBuildingDynamicSelectId(@PathVariable(value = "id") Integer id, HttpSession session){
        ResponseBean  responseBean = iBuildingDynamicService.iBuildingDynamicSelectId(id);
        return responseBean;
    }

    @ApiOperation(value = "微信小程序端项目动态管理列表", notes = "微信小程序端项目动态管理列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "Query",dataType = "Integer",name = "pageNum",value = "分页第几页" ),
            @ApiImplicitParam(paramType = "Query",dataType = "Integer",name = "pageSize",value = "pageSize:每页长度")

    })
    @RequestMapping(value = "/wx/buildingDynamiceList", method = RequestMethod.GET)
    public ResponseBean wxBuildingDynamiceList(@RequestParam("pageNum")Integer pageNum,@RequestParam("pageSize")Integer pageSize, HttpSession session){
        ResponseBean  responseBean = iBuildingDynamicService.getWxBuildingDynamiceList(pageNum,pageSize);
        return responseBean;
    }

    @RequestMapping(value = "/wx/buildingDynamiceInfo/{dynamicId}", method = RequestMethod.GET)
    @ApiOperation(value = "微信小程序项目动态详情", notes = "微信小程序项目动态详情")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass=String.class, name = "dynamicId", value = "项目动态dynamicId"),
    })
    public ResponseBean iBuildingDynamicSelectId(@PathVariable(value = "dynamicId") String dynamicId, HttpSession session){
        ResponseBean  responseBean = iBuildingDynamicService.getWxBuildingDynamiceInfo(dynamicId);
        return responseBean;
    }

    @RequestMapping(value = "/buildingDynamic/add" ,method =RequestMethod.PUT)
    @ApiOperation(value = "动态管理添加",notes="动态管理添加")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "Query",dataTypeClass = String.class,name = "buildingId",value = "楼盘id" ),
            @ApiImplicitParam(paramType = "Query",dataTypeClass = String.class,name = "imgUrl",value = "首页图片" ),
            @ApiImplicitParam(paramType = "Query",dataTypeClass = String.class,name = "title",value = "标题" ),
            @ApiImplicitParam(paramType = "Query",dataTypeClass = String.class,name = "desc",value = "描述" ),
            @ApiImplicitParam(paramType = "Query",dataTypeClass = String.class,name = "url",value = "url" ),
            @ApiImplicitParam(paramType = "Query",dataType = "Date",name = "publishDate",value = "publishDate" )
    })
    public  ResponseBean buildingDynamicAdd(@RequestParam(required = false) String buildingId,
                                         @RequestParam(required = false) String imgUrl,
                                         @RequestParam(required = false) String title,
                                         @RequestParam(required = false) String desc,
                                         @RequestParam(required = false) String url,
                                         @RequestParam(value = "publishDate",required = false) Date publishDate){
        HashMap<Object,Object> map= new HashMap<>();
        map.put("buildingId",buildingId);map.put("imgUrl",imgUrl);map.put("title",title);map.put("desc",desc);map.put("url",url);map.put("publishDate",publishDate);
         ResponseBean responseBean= iBuildingDynamicService.buildingDynamicAdd(map);
         return responseBean;
    }

}
