package com.example.wholeestate.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.common.uuid.IdGen;
import com.example.wholeestate.dao.ActivityEnrollMapper;
import com.example.wholeestate.dao.ActivityMapper;
import com.example.wholeestate.dao.CustomerMapper;
import com.example.wholeestate.model.Activity;
import com.example.wholeestate.model.ActivityEnroll;
import com.example.wholeestate.model.Customer;
import com.example.wholeestate.service.IActivityEnrollService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Map;

/**
 * <p>
 * 活动报名表 服务实现类
 * </p>
 *
 * @author weiximei
 * @since 2019-03-20
 */
@Service
public class ActivityEnrollServiceImpl extends ServiceImpl<ActivityEnrollMapper, ActivityEnroll> implements IActivityEnrollService {

    @Autowired
    private ActivityEnrollMapper activityEnrollMapper;

    @Autowired
    private ActivityMapper activityMapper;

    @Autowired
    private CustomerMapper customerMapper;

    private IdGen idGen = IdGen.get();

    @Override
    public ResponseBean getActivitySignUpList(String activityId, Integer pageNum, Integer pageSize, String customerName, String customerPhone) {
        ResponseBean responseBean = new ResponseBean();

        QueryWrapper<Activity> activityQueryWrapper = new QueryWrapper<>();
        activityQueryWrapper.eq("activity_id", activityId);
        Activity activity = activityMapper.selectOne(activityQueryWrapper);
        if (null == activity) {
            responseBean.addError("活动不存在!");
            return responseBean;
        }

        Page<Map<String, Object>> page = new Page<>();
        page.setCurrent(pageNum == null ? 1 : pageNum);
        page.setSize(pageSize == null ? 10 : pageSize);
        IPage<Map<String, Object>> activityEnrollIPage = activityEnrollMapper.selectPageActivityEnroll(page, activityId, customerName, customerPhone);

        responseBean.addSuccess(activityEnrollIPage);
        return responseBean;
    }

    @Override
    public ResponseBean getOpenidActivityUpList(String openid, Integer pageNum, Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();
        Page<Activity> page = new Page<>();
        page.setCurrent(pageNum);
        page.setSize(pageSize);
        IPage<Activity> activityIPage = activityEnrollMapper.selectOpenidActivityEnroll(page, openid);
        responseBean.addSuccess(activityIPage);
        return responseBean;
    }

    @Override
    public ResponseBean wxSignUpActivity(String openid, String parameter) {
        ResponseBean responseBean = new ResponseBean();

        QueryWrapper<Customer> customerQueryWrapper = new QueryWrapper<>();
        customerQueryWrapper.eq("openid", openid);
        Customer customer = customerMapper.selectOne(customerQueryWrapper);
        if (null == customer) {
            responseBean.addError("用户不存在!");
            return responseBean;
        }

        ActivityEnroll activityEnroll = JSONObject.parseObject(parameter, ActivityEnroll.class);
        activityEnroll.setCustomerId(customer.getCustomerId());
        activityEnroll.setEnrollId(idGen.nextId()+"");
        int row = activityEnrollMapper.insert(activityEnroll);
        if (row <= 0) {
            responseBean.addError("报名失败!");
            return responseBean;
        }
        responseBean.addSuccess("报名成功!");
        return responseBean;
    }
}
