package com.example.wholeestate.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.wholeestate.common.Constant;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.common.uuid.IdGen;
import com.example.wholeestate.dao.*;
import com.example.wholeestate.model.*;
import com.example.wholeestate.service.IBuildingService;
import com.fasterxml.jackson.databind.util.ArrayBuilders;
import com.google.common.collect.Maps;
import com.sun.org.apache.bcel.internal.generic.NEW;
import net.sf.jsqlparser.expression.DateTimeLiteralExpression;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.time.LocalDateTime;
import java.util.*;

/**
 * <p>
 * 楼盘表 服务实现类
 * </p>
 *
 * @author jobob
 * @since 2019-03-20
 */
@Service
public class BuildingServiceImpl extends ServiceImpl<BuildingMapper, Building> implements IBuildingService {
    @Autowired
    private BuildingMapper buildingMapper;

    @Autowired
    private AppointmentMapper AppointmentMapper;

    @Autowired
    private  CustomerMapper customerMapper;

    @Autowired
    private BuildingImgMapper buildingImgMapper;

    @Autowired
    private ApartmentImgMapper apartmentImgMapper;

    @Autowired
    private  BuildingApartmentMapper buildingApartmentMapper;

    @Autowired
    private BuildingDynamicMapper buildingDynamicMapper;



    private IdGen idGen = IdGen.get();

    @Override
    public ResponseBean buildingList(Integer pageNum,Integer pageSize,String name,String code) {
        ResponseBean response= new ResponseBean();
        Page<Building> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);
         IPage<Building> building= buildingMapper.buildingList(page,name,code);
        List<Building> buildingList=building.getRecords();

        HashMap hashMap= new HashMap<>();
        hashMap.put("list",buildingList);
        hashMap.put("total",building.getTotal());
        hashMap.put("pageNum",building.getCurrent());
        hashMap.put("pageSize",building.getSize());
        response.addSuccess(hashMap);
        return response;
    }

    @Override
    public ResponseBean buildingSelectId(String id) {
        ResponseBean response= new ResponseBean();
        QueryWrapper<Building> buildingtWrapper = new QueryWrapper<>();
        buildingtWrapper.lambda().gt(Building::getStatus,-1);
        buildingtWrapper.lambda().eq(Building::getBuildingId,id);
        Building building= buildingMapper.selectOne(buildingtWrapper);
        //查询当前图片
        QueryWrapper<BuildingImg> BuildingImgQueryWrapper = new QueryWrapper<>();
        BuildingImgQueryWrapper.eq("building_id", id);
        BuildingImgQueryWrapper.eq("img_type", "banner");
       List<BuildingImg> buildingImg= buildingImgMapper.selectList(BuildingImgQueryWrapper);
        building.setBuildingImg(buildingImg);
        response.addSuccess(building);
        return response;
    }

    @Override
    public ResponseBean buildingUpdate(String parameter) {
        ResponseBean response= new ResponseBean();

        JSONObject object= JSONObject.parseObject(parameter);

        Building building = JSONObject.parseObject(parameter,Building.class);
        String imgStr = object.getString("img");
        List<BuildingImg> buildingImgs = JSONObject.parseArray(imgStr, BuildingImg.class);

        QueryWrapper<Building> buildingIdQueryWrapper = new QueryWrapper<>();
        buildingIdQueryWrapper.eq("building_id", building.getBuildingId());
        buildingMapper.update(building,buildingIdQueryWrapper);
        //图片先删除再添加
        QueryWrapper<BuildingImg> BuildingImgQueryWrapper = new QueryWrapper<>();
        BuildingImgQueryWrapper.eq("building_id", building.getBuildingId());
        BuildingImgQueryWrapper.eq("img_type", "banner");
        buildingImgMapper.delete(BuildingImgQueryWrapper);

        for (BuildingImg img:buildingImgs){
            BuildingImg Images = new BuildingImg();
            Images.setImgId(idGen.nextId()+"");
            Images.setBuildingId(building.getBuildingId());
            Images.setImgType(img.getImgType());
            Images.setUrl(img.getUrl());
            Images.setOrderNo(Integer.valueOf(img.getOrderNo()));
            Images.setStatus(0);
            Images.setCreateDate(LocalDateTime.now());
            buildingImgMapper.insert(Images);
        }



        response.addSuccess("成功");
        return response;
    }

    @Override
    public ResponseBean appointmentList(Integer pageNum,Integer pageSize,String buildingId,String username,String phone,String status) {
        ResponseBean response= new ResponseBean();
        Page<Appointment> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 0 : pageNum);
        IPage<Appointment> building= AppointmentMapper.appendableList(page,buildingId,username,phone,status);
        List<Appointment> buildingList=building.getRecords();
        //预约的用户，
//        ArrayList  arrayListUser= new ArrayList<>();

        //预约的楼盘，
//        ArrayList  arrayListbuilding= new ArrayList<>();
//       for (Appointment bui:buildingList){
//          Building buil= new Building();
//           QueryWrapper<Building> buildingtWrapper = new QueryWrapper<>();
//           buildingtWrapper.lambda().eq(Building::getStatus,0);
//           buildingtWrapper.lambda().eq(Building::getBuildingId,bui.getBuildingId());
//           Building bu= buildingMapper.selectOne(buildingtWrapper);
//           arrayListUser.add(bu);
//
//           QueryWrapper<Customer> customerWrapper = new QueryWrapper<>();
//           customerWrapper.lambda().eq(Customer::getStatus,0);
//           customerWrapper.lambda().eq(Customer::getCustomerId,bui.getCustomerId());
//           Customer cust= customerMapper.selectOne(customerWrapper);
//           arrayListbuilding.add(cust);
//           bui.setArrayListUser(arrayListUser);
//           bui.setArrayListbuilding(arrayListbuilding);
//       }
        HashMap hashMap= new HashMap<>();
        hashMap.put("list",buildingList);
        hashMap.put("total",building.getTotal());
        hashMap.put("pageNum",building.getCurrent());
        hashMap.put("pageSize",building.getSize());
        response.addSuccess(hashMap);
        return response;
    }

    @Override
    public ResponseBean buildingAdd(String parameter) {
            ResponseBean response= new ResponseBean();

            JSONObject object= JSONObject.parseObject(parameter);

        Building building = JSONObject.parseObject(parameter,Building.class);
        String imgStr = object.getString("img");
        List<BuildingImg> buildingImgs = JSONObject.parseArray(imgStr, BuildingImg.class);
//            if (!"".equals(building.getBuildingId())&&null!=building.getBuildingId()){
//                response.addError("楼盘名称不能为空");
//                return response;
//            }
//            if (!"".equals(building.getPrice())&&null!=building.getPrice()){
//                response.addError("价格不能为空");
//                return response;
//            }
//            if (!"".equals(building.getOpeningDate())&&null!=building.getOpeningDate()){
//                response.addError("开盘时间");
//                return response;
//            }
            building.setBuildingId(idGen.nextId()+"");
            building.setOpeningDate(object.getDate("openingDate"));
            building.setCreateDate(LocalDateTime.now());
            building.setStatus(0);
        for (BuildingImg img:buildingImgs){
            BuildingImg Images = new BuildingImg();
            Images.setImgId(idGen.nextId()+"");
            Images.setBuildingId(building.getBuildingId());
            Images.setImgType(img.getImgType());
            Images.setUrl(img.getUrl());
            Images.setOrderNo(Integer.valueOf(img.getOrderNo()));
            Images.setStatus(0);
            Images.setCreateDate(LocalDateTime.now());
            buildingImgMapper.insert(Images);
        }
            buildingMapper.insert(building);




            response.addSuccess("成功");
            return response;
        }

    @Override
    public ResponseBean buildingUpdateStatus(String parameter) {
        Building  building= new Building();
        JSONObject jsonobject = JSONObject.parseObject(parameter);
        Integer  status= jsonobject.getInteger("status");
        String id= jsonobject.getString("id");
        QueryWrapper<Building> buildingIdQueryWrapper = new QueryWrapper<>();
        buildingIdQueryWrapper.eq("building_id", id);
        building.setBuildingId(id);
        building.setStatus(status);
        buildingMapper.update(building,buildingIdQueryWrapper);
         ResponseBean ResponseBean= new ResponseBean<>();
        ResponseBean.addSuccess("成功");
        return ResponseBean;
    }

    @Override
    public ResponseBean buildingdelete(String id) {
        ResponseBean responseBean= new ResponseBean<>();
        Building  building= new Building();
        QueryWrapper<Building> buildingtWrapper = new QueryWrapper<>();
        buildingtWrapper.lambda().eq(Building::getBuildingId,id);
        Building bui= buildingMapper.selectOne(buildingtWrapper);

        if (bui.getStatus().equals(2)){
            responseBean.addSuccess("楼盘已发布不可以删除");
            return responseBean;
        }
        QueryWrapper<Building> buildingIdQueryWrapper = new QueryWrapper<>();
        buildingIdQueryWrapper.eq("building_id", id);
        building.setBuildingId(String.valueOf(id));
        building.setStatus(-1);
        buildingMapper.update(building,buildingIdQueryWrapper);
        ResponseBean ResponseBean= new ResponseBean<>();
        ResponseBean.addSuccess("成功");
        return ResponseBean;
    }

    @Override
    public ResponseBean buildingApartmentAdd(String parameter) {
         ResponseBean responseBean= new ResponseBean<>();
         BuildingApartment building = JSONObject.parseObject(parameter,BuildingApartment.class);
        JSONObject jsonobject = JSONObject.parseObject(parameter);
        //图片数组
         String imgStr = jsonobject.getString("img");
         //转集合
         List<BuildingImg> buildingImgs = JSONObject.parseArray(imgStr, BuildingImg.class);
         //插入户型图片
        building.setStatus(1);
        building.setCreateDate(LocalDateTime.now());
        building.setApartmentId(idGen.nextId() + "");
        buildingApartmentMapper.insert(building);
        for (BuildingImg img:buildingImgs){
            BuildingImg Images = new BuildingImg();
            Images.setImgId(idGen.nextId() + "");
            Images.setBuildingId(building.getBuildingId());
            Images.setImgType(img.getImgType());
            Images.setUrl(img.getUrl());
            Images.setOrderNo(Integer.valueOf(img.getOrderNo()));
            Images.setStatus(1);
            Images.setCreateDate(LocalDateTime.now());
            buildingImgMapper.insert(Images);
            //维护楼盘户型对应表
            ApartmentImg apartmentImg= new ApartmentImg();
            apartmentImg.setApartmentId(building.getApartmentId());
            apartmentImg.setImgId(Images.getImgId());
            apartmentImg.setStatus(1);
            apartmentImgMapper.insert(apartmentImg);

        }

        responseBean.addSuccess("成功");
        return responseBean;
    }

    @Override
    public ResponseBean buildingApartmentUpdate(String parameter) {
        ResponseBean responseBean= new ResponseBean<>();
        BuildingApartment building = JSONObject.parseObject(parameter,BuildingApartment.class);
        JSONObject jsonobject = JSONObject.parseObject(parameter);
        //图片数组
        String imgStr = jsonobject.getString("img");
        //转集合
        List<BuildingImg> buildingImgs = JSONObject.parseArray(imgStr, BuildingImg.class);
        //插入户型图片删除之前的图片
        QueryWrapper<BuildingImg> BuildingImgQueryWrapper = new QueryWrapper<>();
        BuildingImgQueryWrapper.eq("building_id", building.getBuildingId());
        BuildingImgQueryWrapper.eq("img_type", "aparment");

        buildingImgMapper.delete(BuildingImgQueryWrapper);
        //删除户户型对应图片表
        QueryWrapper<ApartmentImg> apartmentImgQueryWrapper = new QueryWrapper<>();
        apartmentImgQueryWrapper.eq("apartment_id", building.getApartmentId());
        apartmentImgMapper.delete(apartmentImgQueryWrapper);

        QueryWrapper<BuildingApartment> buildingApartmentQueryWrapper = new QueryWrapper<>();
        buildingApartmentQueryWrapper.eq("apartment_id", building.getApartmentId());
        buildingApartmentMapper.update(building,buildingApartmentQueryWrapper);

        for (BuildingImg img:buildingImgs){
            BuildingImg Images = new BuildingImg();
            Images.setImgId(idGen.nextId() + "");
            Images.setBuildingId(building.getBuildingId());
            Images.setImgType(img.getImgType());
            Images.setUrl(img.getUrl());
            Images.setOrderNo(Integer.valueOf(img.getOrderNo()));
            Images.setStatus(1);
            Images.setCreateDate(LocalDateTime.now());
            buildingImgMapper.insert(Images);
            //维护楼盘户型对应表
            ApartmentImg apartmentImg= new ApartmentImg();
            apartmentImg.setApartmentId(building.getApartmentId());
            apartmentImg.setImgId(Images.getImgId());
            apartmentImg.setStatus(1);
            apartmentImgMapper.insert(apartmentImg);

        }
        responseBean.addSuccess("成功");
        return responseBean;
    }

    @Override
    public ResponseBean buildingApartmentSelectId(String id) {
        ResponseBean responseBean = new ResponseBean();
        //查询户型详情
        QueryWrapper<BuildingApartment> buildingApartmentQueryWrapper = new QueryWrapper<>();
        buildingApartmentQueryWrapper.eq("apartment_id", id);
        //拿到当前户型信息
         BuildingApartment buildingApartment = buildingApartmentMapper.selectOne(buildingApartmentQueryWrapper);
         if ( null == buildingApartment ){
             responseBean.addSuccess("此楼盘没有户型图请上传");
             return responseBean;
         }
         //根据户型ID查楼盘户型对应图片表
        ArrayList arrayList= new ArrayList<>();
        QueryWrapper< ApartmentImg> ApartmentImgQueryWrapper = new QueryWrapper<>();
        ApartmentImgQueryWrapper.eq("apartment_id", buildingApartment.getApartmentId());
        List<ApartmentImg> buildingImg= apartmentImgMapper.selectList(ApartmentImgQueryWrapper);
        for (ApartmentImg apartmentImg:buildingImg){
            QueryWrapper<BuildingImg> buildingImgQueryWrapper = new QueryWrapper<>();
            buildingImgQueryWrapper.eq("img_id",apartmentImg.getImgId());
            buildingImgQueryWrapper.eq("img_type","aparment");
             List<BuildingImg> buildingImgList= buildingImgMapper.selectList(buildingImgQueryWrapper);
             for (BuildingImg buImg:buildingImgList) {
                 arrayList.add(buImg);
             }
        }
        buildingApartment.setBuildingImgList(arrayList);
        responseBean .addSuccess(buildingApartment);
        return responseBean;
    }

    @Override
    public ResponseBean appointmentUpdate(String id,String writeoffRemark) {
        ResponseBean responseBean= new ResponseBean();
       Appointment appointment= new Appointment();
        appointment.setAppointmentId(id);
        appointment.setWriteoffRemark(writeoffRemark);
        appointment.setStatus(2);
//        new DateTimeLiteralExpression.DateTime()
//        appointment.setWriteoffDate(LocalDateTime.now());
        QueryWrapper<Appointment> AppointmentQueryWrapper = new QueryWrapper<>();
        AppointmentQueryWrapper.eq("appointment_id", id);
        AppointmentMapper.update(appointment,AppointmentQueryWrapper);
        responseBean.addSuccess("成功");
        return responseBean;
    }


    @Override
    public ResponseBean getWxBuildingList() {
        ResponseBean responseBean = new ResponseBean();

        QueryWrapper<Building> buildingQueryWrapper = new QueryWrapper<>();
        buildingQueryWrapper.eq("status", 1);
        List<Building> buildingList = buildingMapper.selectList(buildingQueryWrapper);
        responseBean.addSuccess(buildingList);

        return responseBean;
    }

    @Override
    public ResponseBean getWxBuildingById(String buildingId) {
        ResponseBean responseBean = new ResponseBean();

        // 楼盘信息
        QueryWrapper<Building> buildingQueryWrapper = new QueryWrapper<>();
        buildingQueryWrapper.eq("building_id", buildingId);
        Building building = buildingMapper.selectOne(buildingQueryWrapper);
        if (null == building) {
            responseBean.addError("楼盘不存在!");
            return responseBean;
        }

        // 楼盘Banner
        QueryWrapper<BuildingImg> buildingImgBannerQueryWrapper = new QueryWrapper<>();
        buildingImgBannerQueryWrapper.eq("building_id", building.getBuildingId());
        buildingImgBannerQueryWrapper.eq("img_type", Constant.BUILDING_IMG_TYPE_BANNER);
        buildingImgBannerQueryWrapper.orderBy(true, true, "order_no");
        List<BuildingImg> buildingBannerImg = buildingImgMapper.selectList(buildingImgBannerQueryWrapper);

        building.setBuildingImg(buildingBannerImg);

        // 楼盘户型
        QueryWrapper<BuildingApartment> buildingApartmentQueryWrapper = new QueryWrapper<>();
        buildingApartmentQueryWrapper.eq("building_id", building.getBuildingId());
        List<BuildingApartment> buildingApartmentList = buildingApartmentMapper.selectList(buildingApartmentQueryWrapper);

        // 楼盘户型图
        buildingApartmentList.forEach(e -> {
            QueryWrapper<BuildingImg> buildingImgQueryWrapper = new QueryWrapper<>();
            buildingImgQueryWrapper.eq("building_id", building.getBuildingId());
            List<BuildingImg> buildingImgList = buildingImgMapper.selectList(buildingImgQueryWrapper);
            e.setBuildingImgList(buildingImgList);
        });

        // 项目最新动态
        QueryWrapper<BuildingDynamic> buildingDynamicQueryWrapper = new QueryWrapper<>();
        buildingApartmentQueryWrapper.eq("building_id", building.getBuildingId());
        buildingApartmentQueryWrapper.orderByDesc("create_date");
        Page<BuildingDynamic> page = new Page<>();
        page.setCurrent(1);
        page.setSize(1);
        IPage<BuildingDynamic> buildingDynamicIPage = buildingDynamicMapper.selectPage(page, buildingDynamicQueryWrapper);
        List<BuildingDynamic> records = buildingDynamicIPage.getRecords();

        Map<String, Object> buildingMap = Maps.newHashMap();
        buildingMap.put("info", building);
        buildingMap.put("buildingApartment", buildingApartmentList);
        buildingMap.put("buildingDynamic", records);

        responseBean.addSuccess(buildingMap);

        return responseBean;
    }

    @Override
    public ResponseBean buildingApartmentBuildingId(String id) {
        ResponseBean responseBean= new ResponseBean();
        QueryWrapper<BuildingApartment> buildingApartmentQueryWrapper = new QueryWrapper<>();
        buildingApartmentQueryWrapper.eq("building_id", id);
         List<BuildingApartment> buildingApartment= buildingApartmentMapper.selectList(buildingApartmentQueryWrapper);
         responseBean.addSuccess(buildingApartment);
         return responseBean;
    }
}
